input — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# input

Collect input from the keyboard.

class `input.` `Keyboard`

  Collects input from the keyboard.

  `finish_writing`()

    Return the keyboard to normal operation after Eric has finished writing on a blackboard.

  `got_quit`()

    Return whether the window close button was clicked.

  `is_pressed`(keys)

    Return whether any one of a set of keys is being pressed, or False if Eric is writing on a blackboard at the moment.

    Parameters: | keys – A list of keys to check.

  `pressed`(keys)

    Return whether any one of a set of keys either is being pressed or was pressed since the last keyboard check.

    Parameters: | keys – A list of keys to check.

  `pump`()

    Process the input event queue.

  `start_writing`()

    Prepare the keyboard for Eric writing on a blackboard, during which time keypresses are echoed on the blackboard instead of making Eric move.

  `was_pressed`(keys, force_check=False)

    Return whether any one of a set of keys was pressed since the last keyboard check.

    Parameters: | keys – A list of keys to check. force_check – If True, check keys even if Eric is writing on a blackboard.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »